@@ -21,7 +21,7 @@ SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/api/cli/v1'
 #SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
 LANGUAGES = ['ruby', 'javascript', 'typescript', 'python', 'php',
              'java', 'nodejs', 'license', 'go', 'python2']
-SCANNERS = ['sast', 'dast', 'sca']
+SCANNERS = ['sast', 'dast', 'sca', 'secrets']
 SECRETS = ['gitleaks']
 config = {}
 parsed_args = {}
@@ -143,6 +143,9 @@ def select_scanner():
         elif scanner == 'license':
             print('License scanner selected')
             run_sast('license')
+        elif scanner == 'secrets':
+            print('secrets scanner selected')
+            run_sast('gitleaks')
         elif scanner == 'dast':
             print('DAST scanner selected')
             dast_vars = config['variables']
@@ -172,7 +175,7 @@ def run_scan(scanner_type, scan_config):
 
         if os.path.exists(out_file):
             timestamp = upload_output(out_file, timing_file)
-            trigger_etl(timestamp, ntpath.basename(out_file), scan_config['scanner'])
+            trigger_etl(timestamp, ntpath.basename(out_file), scan_config['scanner'], os.path.getsize(out_file) <= 0)
     except Exception as e:
         global scan_error_occurred
         scan_error_occurred = True
@@ -211,14 +214,6 @@ def run_sast(p_code_lang=None):
 
     build_dir = get_build_dir()
     code_lang = code_lang.lower()
-    #secrets
-    if 'secrets' in config:
-        secrets = config['secrets'].lower()
-        if secrets in SECRETS:
-            code_lang = code_lang + ',' + secrets
-        else:
-            print('Unsupported secrets config: ' + secrets)
-
     languages = code_lang.split(',')
 
     for code_lang in languages:
@@ -305,10 +300,10 @@ def upload_output(output_file, timing_file):
 
     return timestamp
 
-def trigger_etl(timestamp, fileName, scanner):
+def trigger_etl(timestamp, fileName, scanner, output_empty):
     print('ETL started')
     try:
-        payload = {'appId': config['appid'], 'apiId': config['apiid'], 'timestamp': timestamp, 'fileName': fileName, 'scanner': scanner}
+        payload = {'appId': config['appid'], 'apiId': config['apiid'], 'timestamp': timestamp, 'fileName': fileName, 'scanner': scanner, 'fileEmpty': output_empty}
         resp = requests.get(SKEN_SERVER_BASE_URL + "/doETL", params=payload)
         etl_result = resp.json()
 
@@ -327,7 +322,6 @@ def main():
     parser.add_argument('-p' ,'--path', metavar='project path', help='path of the project to be scanned.')
     parser.add_argument('--dast_url', metavar='DAST URL', help='URL to be scanned.')
     parser.add_argument('--dast_full_scan', metavar='DAST full scan', choices=['yes', 'no'], help='DAST full scan or quick scan.')
-    parser.add_argument('--secrets', metavar='secrets config', help='secrets config.')
 
     parser.add_argument('--api_id', metavar='API Id', help='API Id.')
     parser.add_argument('--app_id', metavar='Application Id', help='Application Id.')
